package
Version:
v1.0.0
Opens a new window with list of versions in this module.
Published: Jul 8, 2026
License: MIT
Opens a new window with license information.
Imports: 1
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type Clock interface {
Now() time.Time
}
Clock allows to mock time.Now() in tests.
MockClock returns a canned time.
Now returns the mocked time.
type SystemClock struct{}
SystemClock returns system time.
Now returns the current local time.
Source Files
¶
Click to show internal directories.
Click to hide internal directories.